# Justicia
This is the implementation of our [AAAI-2021 paper](https://arxiv.org/pdf/2009.06516.pdf).

## Install
- Install the python library
`pip install justicia`
- Install other python dependencies
`pip install -r requirements.txt`

### Other dependencies
- [SSAT solver](https://github.com/nianzelee/ssatABC)
- [PySAT](https://github.com/pysathq/pysat)
